"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.processDistance = void 0;
const intersect_1 = __importDefault(require("intersect"));
const utilities_1 = require("./utilities");
const Levenshtein = require('levenshtein-sse');
function processDistance({ mainFingerprint, candidate, variables, }) {
    const distanceStart = process.hrtime.bigint();
    // If disqualified, candidate is null.
    const resultObject = {
        candidate: null,
        byIntersection: 0,
        byDistance: 0,
        byThreshold: 0,
    };
    if (mainFingerprint.fingerprint == candidate.fingerprint) {
        return resultObject; // ignore the main fingerprint
    }
    /* Remove candidates that don't meet threshold (minimum callstack length). */
    if (candidate.callstack.length < variables.threshold) {
        resultObject.byThreshold++;
        return resultObject;
    }
    /* Truncate the callstack. This is done *after* checking threshold. */
    candidate.callstack = candidate.callstack.slice(0, variables.truncate + 1);
    /* We require some matching frames to even be considered for eligibility. */
    if (intersect_1.default(candidate.callstack, mainFingerprint.callstack).length <
        variables.intersection) {
        resultObject.byIntersection++;
        return resultObject;
    }
    /* Compute the edit distance. */
    const distance = Levenshtein(candidate.callstack, mainFingerprint.callstack);
    if (distance > variables.distance) {
        resultObject.byDistance++;
        return resultObject;
    }
    /* Successful candidate - generate callstack diff and return results */
    const { mainCallstackDiff, candidateCallstackDiff } = utilities_1.getCallstackDiff(candidate.callstack, mainFingerprint.callstack);
    resultObject.candidate = {
        ...candidate,
        mainCallstackDiff,
        candidateCallstackDiff,
        distance,
        meta: {
            timing: {
                distance: (process.hrtime.bigint() - distanceStart).toString(),
            },
        },
    };
    return resultObject;
}
exports.processDistance = processDistance;
//# sourceMappingURL=distance.js.map